<?php
/**
 * Up Front WP functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, up_front_wp_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)
 *     remove_filter( 'excerpt_length', 'up_front_wp_excerpt_length' );
 *     ...
 * }
 * </code>
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package Up_Front_WP
 * @since Up Front WP 1.0
 */

/*
 * Set the content width based on the theme's design and stylesheet.
 *
 * Used to set the width of images and content. Should be equal to the width the theme
 * is designed for, generally via the style.css stylesheet.
 */
global $content_width;
if ( ! isset( $content_width ) ) $content_width = 900;

/* Tell WordPress to run up_front_wp_setup() when the 'after_setup_theme' hook is run. */
add_action( 'after_setup_theme', 'up_front_wp_setup' );

if ( ! function_exists( 'up_front_wp_setup' ) ):
/**
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override up_front_wp_setup() in a child theme, add your own up_front_wp_setup to your child theme's
 * functions.php file.
 *
 * @uses add_theme_support()        To add support for post thumbnails, custom headers and backgrounds, and automatic feed links.
 * @uses register_nav_menus()       To add support for navigation menus.
 * @uses add_editor_style()         To style the visual editor.
 * @uses load_theme_textdomain()    For translation/localization support.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size()  To set a custom post thumbnail size.
 *
 * @since Up Front WP 1.0
 */
function up_front_wp_setup() {
	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style( 'editor-style.css' );
	
	// Post Format support.
	add_theme_support( 'post-formats', array( 'aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio', 'chat' ) );
	
	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );
	
  // Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'up-front-wp' ),
		'footer' => __( 'Footer Links', 'up-front-wp' ),
	) );
	
	// The custom header business starts here.
	
	$args = array(
		// The height and width of our custom header.
		'width'         => '980',
		'height'        => '170',
		// Support flexible widths and heights.
		'flex-height'    => true,
		'flex-width'    => true,
		// Let WordPress know what our default text color is.
		'default-text-color'     => '333',
	);
	add_theme_support( 'custom-header', $args );

        // This theme supports custom logos.
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-width' => true,
	) );
	
	// This theme allows users to set a custom background.
	$args = array(
		// Let WordPress know what our default background color is.
		'default-color' => 'fff',
	);
	add_theme_support( 'custom-background', $args );
	
	// This feature allows themes to add document title tag to HTML <head>.
	add_theme_support( 'title-tag' );

	// Register Custom Navigation Walker
	require_once('inc/nav-menu.php');	
}
add_action( 'after_setup_theme', 'up_front_wp_setup' );
endif;

/**
 * Enqueue scripts and styles for front-end.
 *
 * @since Up Front WP 1.0
 */
function up_front_wp_scripts() {
	if ( !is_front_page() || is_home() ) {
		wp_enqueue_style( 'up-front-wp-blog-css', get_template_directory_uri() . '/css/blog.css' );
	}
	wp_enqueue_style( 'up-front-wp-bootstrap-css', get_template_directory_uri() . '/css/bootstrap.css', '3.3.0' );
	wp_enqueue_style( 'up-front-wp-font-awesome-css', get_template_directory_uri() . '/css/font-awesome.css', '4.2.0' );
	wp_enqueue_style( 'up-front-wp-open-sans-css', get_template_directory_uri() . '/css/open-sans.css' );
	if ( !get_theme_mod( 'responsive_layout', 1 ) ) {
	  wp_enqueue_style( 'up-front-wp-non-responsive-css', get_template_directory_uri() . '/css/non-responsive.css' );
	} else {
	  wp_enqueue_style( 'up-front-wp-queries-css', get_template_directory_uri() . '/css/queries.css' );
	}
	wp_enqueue_style( 'up-front-wp-sintony-css', get_template_directory_uri() . '/css/sintony.css' );
	wp_enqueue_style( 'up-front-wp-styles-css', get_template_directory_uri() . '/css/styles.css' );
	if ( is_rtl() ) {
		if ( !is_front_page() ) {
			wp_enqueue_style( 'up-front-wp-blog-rtl-css', get_template_directory_uri() . '/css/blog-rtl.css' );
		}
		wp_enqueue_style( 'up-front-wp-bootstrap-rtl-css', get_template_directory_uri() . '/css/bootstrap-rtl.css', '3.3.0' );
		if ( !get_theme_mod( 'responsive_layout', 1 ) ) {
		  wp_enqueue_style( 'up-front-wp-non-responsive-rtl-css', get_template_directory_uri() . '/css/non-responsive-rtl.css' );
		} else {
		  wp_enqueue_style( 'up-front-wp-queries-rtl-css', get_template_directory_uri() . '/css/queries-rtl.css' );
		}
		wp_enqueue_style( 'up-front-wp-styles-rtl-css', get_template_directory_uri() . '/css/styles-rtl.css' );
	}
	wp_enqueue_style( 'up-front-wp-ie-10-viewport-bug-workaround-css', get_template_directory_uri() . '/css/ie10-viewport-bug-workaround.css', '3.3.0' );
	wp_enqueue_style( 'up-front-wp-style-css', get_stylesheet_uri() );
	wp_enqueue_script( 'up-front-wp-holder-js', get_template_directory_uri() . '/js/holder.min.js', array(), '2.9.4', true );
	wp_enqueue_script( 'up-front-wp-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array( 'jquery' ), '3.3.0', true );
	wp_enqueue_script( 'up-front-wp-html5shiv-js', get_template_directory_uri() . '/js/html5shiv.js', array( 'jquery' ), '3.7.2' );
	wp_enqueue_script( 'up-front-wp-ie-10-viewport-bug-workaround-js', get_template_directory_uri() . '/js/ie10-viewport-bug-workaround.js', array( 'jquery' ), '3.3.0', true );
	wp_enqueue_script( 'up-front-wp-respond-js', get_template_directory_uri() . '/js/respond.js', array( 'jquery' ) );
	wp_enqueue_script( 'up-front-wp-scripts-js', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'up-front-wp-unslider-js', get_template_directory_uri() . '/js/unslider.js', array( 'jquery' ), '', true );
	if ( is_rtl() ) {
		wp_enqueue_script( 'up-front-wp-unslider-rtl-js', get_template_directory_uri() . '/js/unslider-rtl.js', array( 'jquery' ), '', true );
	}
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'up_front_wp_scripts' );

/**
 * Register widgetized areas, including main sidebar and three widget-ready columns in the footer.
 *
 * To override up_front_wp_widgets_init() in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @since Up Front WP 1.0
 *
 * @uses register_sidebar()
 */
function up_front_wp_widgets_init() {
	// Area 1, located at the top of the sidebar.
    register_sidebar( array(
        'name' => __( 'Primary Widget Area', 'up-front-wp' ),
        'id' => 'primary-widget-area',
        'description' => __( 'Add widgets here to appear in your sidebar.', 'up-front-wp' ),
		'before_widget' => '<div id="%1$s" class="sidebar-module widget %2$s">',
		'after_widget'  => '</div>',
        'before_title' => '<h4>',
        'after_title' => '</h4>',
    ) );
	
	// Area 2, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'First Footer Widget Area', 'up-front-wp' ),
		'id'            => 'first-footer-widget-area',
		'description' => __( 'An optional widget area for your site footer.', 'up-front-wp' ), 
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	  
	// Area 3, located in the footer. Empty by default.  
	register_sidebar( array(
		'name' => __( 'Second Footer Widget Area', 'up-front-wp' ),
		'id'            => 'second-footer-widget-area',
		'description' => __( 'An optional widget area for your site footer.', 'up-front-wp' ), 
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	  
	// Area 4, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Third Footer Widget Area', 'up-front-wp' ),
		'id'            => 'third-footer-widget-area',
		'description' => __( 'An optional widget area for your site footer.', 'up-front-wp' ), 
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	
	// Area 5, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Fourth Footer Widget Area', 'up-front-wp' ),
		'id'            => 'fourth-footer-widget-area',
		'description' => __( 'An optional widget area for your site footer.', 'up-front-wp' ), 
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'up_front_wp_widgets_init' );

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since Up Front 1.0
 *
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function up_front_wp_excerpt_more( $link ) {
	if ( is_admin() ) {
		return $link;
	}

	if ( ! is_page_template( 'page-templates/front-page.php' ) ) {
		$link = sprintf( '<p class="link-more"><a href="%1$s" class="more-link">%2$s</a></p>',
			esc_url( get_permalink( get_the_ID() ) ),
			/* translators: %s: Name of current post */
			sprintf( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'up-front-wp' ), get_the_title( get_the_ID() ) )
		);
		return ' &hellip; ' . $link;
    }
}
add_filter( 'excerpt_more', 'up_front_wp_excerpt_more' );

/**
 * Contains methods for customizing the theme customization screen.
 * 
 * @link http://codex.wordpress.org/Theme_Customization_API
 * @since Up Front WP 1.0
 */
class Up_Front_WP_Customize {
   /**
    * This hooks into 'customize_register' (available as of WP 3.4) and allows
    * you to add new sections and controls to the Theme Customize screen.
    * 
    * Note: To enable instant preview, we have to actually write a bit of custom
    * javascript. See live_preview() for more.
    *  
    * @see add_action('customize_register',$func)
    * @param \WP_Customize_Manager $wp_customize
    * @link http://ottopress.com/2012/how-to-leverage-the-theme-customizer-in-your-own-themes/
    * @since Up Front WP 1.0
    */
   public static function register ( $wp_customize ) {
	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'responsive_layout', 
         array(
            'title' => __( 'Responsive Layout', 'up-front-wp' ), //Visible title of section
            'priority' => 1, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
         ) 
      );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'responsive_layout', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'responsive_layout', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Enable Responsiveness', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'responsive_layout', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'responsive_layout', //Which setting to load and manipulate (serialized is okay)
            'priority' => 1, //Determines the order this control appears in for the specified section
      ) );
	  
	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'frontpage_template', 
         array(
            'title' => __( 'Front Page Template', 'up-front-wp' ), //Visible title of section
            'priority' => 2, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
         ) 
      );

	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_stickycarousel', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_stickycarousel', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Display Sticky Carousel', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_stickycarousel', //Which setting to load and manipulate (serialized is okay)
            'priority' => 2, //Determines the order this control appears in for the specified section
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_statuscarousel', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_statuscarousel', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Display Status Carousel', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_statuscarousel', //Which setting to load and manipulate (serialized is okay)
            'priority' => 3, //Determines the order this control appears in for the specified section
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_asideposts', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_asideposts', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Display Aside Post(s)', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_asideposts', //Which setting to load and manipulate (serialized is okay)
            'priority' => 4, //Determines the order this control appears in for the specified section
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_latestarticles', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_latestarticles', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Display Latest Article(s)', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_latestarticles', //Which setting to load and manipulate (serialized is okay)
            'priority' => 5, //Determines the order this control appears in for the specified section
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_laptopslider', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_laptopslider', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Display Laptop Slider', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_laptopslider', //Which setting to load and manipulate (serialized is okay)
            'priority' => 6, //Determines the order this control appears in for the specified section
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_quoteslideshow', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_quoteslideshow', //Set a unique ID for the control
         array(
		 	'type' => 'checkbox', //Set input type for the control 
            'label' => __( 'Display Quote Slideshow', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_quoteslideshow', //Which setting to load and manipulate (serialized is okay)
            'priority' => 7, //Determines the order this control appears in for the specified section
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'button_color', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 'default', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_button_color',
         ) 
      );
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'button_color', //Set a unique ID for the control
         array(
		 	'type' => 'radio', //Set input type for the control 
            'label' => __( 'Button Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'button_color', //Which setting to load and manipulate (serialized is okay)
            'priority' => 8, //Determines the order this control appears in for the specified section
			'choices'  => array(
			'default'  => __( 'Default Color', 'up-front-wp' ),
			'extra' => __( 'Extra Color', 'up-front-wp' ),
			),
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'button_extracolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#455357', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'button_extracolor', //Set a unique ID for the control
         array(
            'label' => __( 'Extra Button Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'frontpage_template', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'button_extracolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 9, //Determines the order this control appears in for the specified section
         ) 
      ) );

	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'logo_options', 
         array(
            'title' => __( 'Logo Options', 'up-front-wp' ), //Visible title of section
            'priority' => 3, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
         ) 
      );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_logo_frontpage', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_logo_frontpage', //Set a unique ID for the control
         array(
		    'type' => 'checkbox', //Set input type for the control
            'label' => __( 'On Frontpage Template', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'logo_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_logo_frontpage', //Which setting to load and manipulate (serialized is okay)
            'priority' => 2, //Determines the order this control appears in for the specified section
         ) 
      );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'display_logo_blogheader', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 1, //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_checkbox',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_logo_blogheader', //Set a unique ID for the control
         array(
		    'type' => 'checkbox', //Set input type for the control
            'label' => __( 'On Blog Header', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'logo_options', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'display_logo_blogheader', //Which setting to load and manipulate (serialized is okay)
            'priority' => 3, //Determines the order this control appears in for the specified section
         ) 
      );
	  
	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'title_tagline', 
         array(
            'title' => __( 'Site Title & Tagline', 'up-front-wp' ), //Visible title of section
            'priority' => 4, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
         ) 
      );
	  
	  //1. Define a new section (if desired) to the Theme Customizer
	  $wp_customize->add_panel( 'custom_header', 
	     array(
			'title' => __( 'Custom Header', 'up-front-wp' ), //Visible title of section
			'priority' => 4, //Determines what order this appears in
			'capability' => 'edit_theme_options', //Capability needed to tweak
			'description' => __( 'Displayed on all posts and pages.', 'up-front-wp' ), //Descriptive tooltip
	     ) 
	  );
	  
	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'header_layout', 
         array(
            'title' => __( 'Header Layout', 'up-front-wp' ), //Visible title of section
            'priority' => 1, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
	    'panel'  => 'custom_header', //Panel group for section
         ) 
      );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'header_width', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => 'full_width', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'up_front_wp_sanitize_header_layout',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'header_width', //Set a unique ID for the control
         array(
		 	'type' => 'radio', //Set input type for the control
            'section' => 'header_layout', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'header_width', //Which setting to load and manipulate (serialized is okay)
            'priority' => 1, //Determines the order this control appears in for the specified section
			'choices' => array(
				'full_width' => __( 'Full-width', 'up-front-wp' ),
				'narrow' => __( 'Narrow', 'up-front-wp' ),
         )
      ) );
	  
	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'header_image', 
         array(
            'title' => __( 'Header Image', 'up-front-wp' ), //Visible title of section
            'priority' => 2, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
	    'panel'  => 'custom_header', //Panel group for section
         ) 
      );

	  //1. Define a new section (if desired) to the Theme Customizer
      $wp_customize->add_section( 'header_text', 
         array(
            'title' => __( 'Header Text', 'up-front-wp' ), //Visible title of section
            'priority' => 3, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
	    'panel'  => 'custom_header', //Panel group for section
         ) 
      );
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( 
         'display_header_text', //Set a unique ID for the control
         array(
		    'type' => 'checkbox', //Set input type for the control
            'label' => __( 'Display Header Text', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'header_text', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'header_textcolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 1, //Determines the order this control appears in for the specified section
         ) 
      );
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'header_textcolor', //Set a unique ID for the control
         array(
            'label' => __( 'Header Text Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'header_text', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'header_textcolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 2, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'primarycolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#63c6ae', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'primarycolor', //Set a unique ID for the control
         array(
            'label' => __( 'Primary Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'primarycolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 1, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'secondarycolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#fff', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'secondarycolor', //Set a unique ID for the control
         array(
            'label' => __( 'Secondary Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'secondarycolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 2, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'tertiarycolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#242a2c', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'postMessage', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'tertiarycolor', //Set a unique ID for the control
         array(
            'label' => __( 'Tertiary Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'tertiarycolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 3, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'menu_textcolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#586165', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'menu_textcolor', //Set a unique ID for the control
         array(
            'label' => __( 'Menu Text Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'menu_textcolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 4, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'heading_textcolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#737c85', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'postMessage', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'heading_textcolor', //Set a unique ID for the control
         array(
            'label' => __( 'Heading Text Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'heading_textcolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 5, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'post_textcolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#929da5', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'postMessage', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );  
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'post_textcolor', //Set a unique ID for the control
         array(
            'label' => __( 'Post Text Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'post_textcolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 6, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'footer_textcolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#454e51', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'postMessage', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );      
            
      //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'footer_textcolor', //Set a unique ID for the control
         array(
            'label' => __( 'Footer Text Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'footer_textcolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 7, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'footer_hovercolor', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#687579', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );      
            
      //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'footer_hovercolor', //Set a unique ID for the control
         array(
            'label' => __( 'Footer Link Hover Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'footer_hovercolor', //Which setting to load and manipulate (serialized is okay)
            'priority' => 8, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //2. Register new settings to the WP database...
      $wp_customize->add_setting( 'header_color', //No need to use a SERIALIZED name, as `theme_mod` settings already live under one db record
         array(
            'default' => '#eee', //Default setting/value to save
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'postMessage', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
			'sanitize_callback' => 'sanitize_hex_color',
         ) 
      );      
            
      //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'header_color', //Set a unique ID for the control
         array(
            'label' => __( 'Header Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'header_color', //Which setting to load and manipulate (serialized is okay)
            'priority' => 9, //Determines the order this control appears in for the specified section
         ) 
      ) );
	  
	  //3. Finally, we define the control itself (which links a setting to a section and renders the HTML controls)...
      $wp_customize->add_control( new WP_Customize_Color_Control( //Instantiate the color control class
         $wp_customize, //Pass the $wp_customize object (required)
         'background_color', //Set a unique ID for the control
         array(
            'label' => __( 'Background Color', 'up-front-wp' ), //Admin-visible name of the control
            'section' => 'colors', //ID of the section this control should render in (can be one of yours, or a WordPress default section)
            'settings' => 'background_color', //Which setting to load and manipulate (serialized is okay)
            'priority' => 10, //Determines the order this control appears in for the specified section
         ) 
      ) );
      
      //4. We can also change built-in settings by modifying properties. For instance, let's make some stuff use live preview JS...
      $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
      $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
	  $wp_customize->add_setting( 'display_header_text' , array( 'default' => 1, 'sanitize_callback' => 'up_front_wp_sanitize_checkbox' ) );
	  $wp_customize->get_setting( 'display_header_text' )->transport = 'postMessage';
      $wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage'; 
   }

   /**
    * This will output the custom WordPress settings to the live theme's WP head.
    * 
    * Used by hook: 'wp_head'
    * 
    * @see add_action('wp_head',$func)
    * @since Up Front WP 1.0
    */
   public static function header_output() {
      ?>
	  <!--Customizer CSS-->
      <style type="text/css">
	    .blog-title, 
		.blog-description {
		  color: #<?php echo esc_html ( get_theme_mod( 'header_textcolor' ) ); ?>;
		}
	    a, a:hover, 
		a:focus, 
		nav ul li a:hover, 
		nav ul li a:focus, 
		nav ul li a.active, 
		.pager > li > a, 
		.hero-btn:hover, 
		.ca-hover:hover .carousel-content h3, 
		.ca-hover:hover .carousel-content p, 
		.next:hover, 
		.prev:hover, 
		.quote-next:hover, 
		.quote-prev:hover {
		  color: #<?php echo esc_html ( get_theme_mod( 'primarycolor' ) ); ?>;
		}
		.logo, 
		.logo-bg, 
		.hero-title, 
		.h2-wrap, 
		.quote-container, 
		.shadow-container {
		  background-color: #<?php echo esc_html ( get_theme_mod( 'primarycolor' ) ); ?>;
		}
		.ca-hover:hover .av0, 
		.ca-hover:hover .av1, 
		.ca-hover:hover .av2, 
		.ca-hover:hover .av3, 
		.ca-hover:hover .av4, 
		.overlay {
		  border-color: #<?php echo esc_html ( get_theme_mod( 'primarycolor' ) ); ?>;
		}
		.logo, 
		.logo-text > a, 
		.logo-text > a:hover, 
		.logo-text > a:focus, 
		.hero-title, 
		.hero-content, 
		.hero-btn, 
		.vert-center,  
		.standard-block, 
		.quote-slideshow h2, 
		.quote-slideshow figcaption, 
		.quote-slideshow a, 
		.quote-slideshow a:hover, 
		.quote-slideshow a:focus, 
		.next, 
		.prev, 
		.quote-next, 
		.quote-prev {
		  color: #<?php echo esc_html ( get_theme_mod( 'secondarycolor' ) ); ?>;
		}
		.banner.first .dots li.active {
		  background-color: #<?php echo esc_html ( get_theme_mod( 'secondarycolor' ) ); ?>;	
		}
		.banner.first .dots li.active, 
		.banner.first .dots li.active, 
		.banner.first .dots li:hover, 
		.banner.first .dots li:focus {
		  border-color: #<?php echo esc_html ( get_theme_mod( 'secondarycolor' ) ); ?>;
		}
		.hero-content, 
		.laptop-slider, 
		footer {
		  background-color: #<?php echo esc_html ( get_theme_mod( 'tertiarycolor' ) ); ?>;
		}
		@media screen and (max-width: 1200px) {
		  <?php if ( get_theme_mod( 'responsive_layout', 1 ) ) : ?>
 		    nav li, nav ul li a {
			  background-color: #<?php echo esc_html ( get_theme_mod( 'tertiarycolor' ) ); ?>;
			}
		  <?php else: ?>
			nav li, nav ul li a { 
			  background-color: transparent !important; 
			}
		  <?php endif; ?>
		}
		nav ul li a {
		  color: #<?php echo esc_html ( get_theme_mod( 'menu_textcolor' ) ); ?>;
		}
		<?php
		$hex_button_extra = get_theme_mod( 'button_extracolor', '#455357' );
		$rgb_button_extra = up_front_wp_hex2rgb($hex_button_extra);
		if( get_theme_mod( 'button_color') == 'default' ) : ?>
		  .hero-btn { 
		    background-color: rgba(0, 0, 0, 0.2);
		  }
		  .hero-btn:hover { 
		    background-color: rgba(0, 0, 0, 0.4);
		  }
		  .button.aside { 
		    background-color: #<?php echo esc_html ( get_theme_mod( 'primarycolor' ) ); ?>; 
		  }
		<?php 
		elseif ( get_theme_mod( 'button_color') == 'extra' ) : 
		?>
		  .hero-btn { 
		    background-color: rgba(<?php echo $rgb_button_extra; ?>, 0.2);
		  }
		  .hero-btn:hover { 
		    background-color: rgba(<?php echo $rgb_button_extra; ?>, 0.4);
		  }
		  .button.aside { 
			background-color: <?php echo esc_attr ( get_theme_mod( 'button_extracolor', '#455357' ) ); ?>; 
	      }
		<?php endif; ?>
		.carousel-content h3, 
		.text-inter h3, 
		.text-inter h3 a, 
		.blog-main h1, 
		.blog-main .h1, 
		.blog-main h2, 
		.blog-main .h2, 
		.blog-main h3, 
		.blog-main .h3, 
		.blog-main h4, 
		.blog-main .h4, 
		.blog-main h5, 
		.blog-main .h5, 
		.blog-main h6, 
		.blog-main .h6, 
		.blog-main-left h1, 
		.blog-main-left .h1, 
		.blog-main-left h2, 
		.blog-main-left .h2, 
		.blog-main-left h3, 
		.blog-main-left .h3, 
		.blog-main-left h4, 
		.blog-main-left .h4, 
		.blog-main-left h5, 
		.blog-main-left .h5, 
		.blog-main-left h6, 
		.blog-main-left .h6, 
		.blog-main-right h1, 
		.blog-main-right .h1, 
		.blog-main-right h2, 
		.blog-main-right .h2, 
		.blog-main-right h3, 
		.blog-main-right .h3, 
		.blog-main-right h4, 
		.blog-main-right .h4, 
		.blog-main-right h5, 
		.blog-main-right .h5, 
		.blog-main-right h6, 
		.blog-main-right .h6, 
		.blog-sidebar, 
		.blog-sidebar-left, 
		.blog-sidebar-right {
		  color: <?php echo esc_attr ( get_theme_mod( 'heading_textcolor' ) ); ?>;
		 
		}
		.carousel-content p, 
		.text-inter p, 
		.blog-main, 
		.blog-main-left, 
		.blog-main-right, 
		.blog-post-meta, 
		.comment-meta {
		  color: <?php echo esc_attr ( get_theme_mod( 'post_textcolor' ) ); ?>;
		}
		footer, 
		footer a, 
		footer .logo-text > a, 
		.footer-links li a {
		  color: <?php echo esc_attr ( get_theme_mod( 'footer_textcolor' ) ); ?>;
		}
		footer a:hover, 
		footer a:focus, 
		footer .logo-text > a:hover, 
		footer .logo-text > a:focus, 
		.footer-links li a:hover, 
		.footer-links li a:focus {
		  color: <?php echo esc_attr ( get_theme_mod( 'footer_hovercolor' ) ); ?>;
		}
		.blog-header {
		  background-color: <?php echo esc_attr ( get_theme_mod( 'header_color' ) ); ?>;
		}
		body, header, nav, .fa-bars {
		  background-color: #<?php echo esc_html ( get_theme_mod( 'background_color' ) ); ?>;
		}
		.banner.second .dots li.active {
		  border-color: #<?php echo esc_html ( get_theme_mod( 'background_color' ) ); ?>;	
		}
		.arrow {
		  border-bottom-color: #<?php echo esc_html ( get_theme_mod( 'background_color' ) ); ?>;	
		}
		<?php 
		  $header_text_color = get_header_textcolor(); 
		?>
		.blog-title,
		.blog-description {
		  color: #<?php echo esc_html ( $header_text_color ); ?>;
		}
		<?php
		  $header_image = get_header_image(); 
		?>
		.blog-header.has-image.has-text {
		  background-image: url( '<?php echo esc_url( $header_image ); ?>'); 
		}
		.blog-header.has-image.no-text {
		  background-image: url( '<?php echo esc_url( $header_image ); ?>');
		}
		<?php if ( get_theme_mod( 'display_stickycarousel', 1 ) ) : ?>
		  .banner.first { 
		    display: block; 
		  }
		<?php else: ?>
		  .banner.first { 
		    display: none; 
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_statuscarousel', 1 ) ) : ?>
		  .container.carousel { 
		    display: block; 
		  }
		<?php else: ?>
		  .container.carousel { 
		    display: none; 
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_asideposts', 1 ) ) : ?>
		  .text-inter { 
		    display: block; 
		  }
		<?php else: ?>
		  .text-inter { 
		    display: none; 
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_latestarticles', 1 ) ) : ?>
		  .h2-wrap, 
		  .container-fluid.container-articles { 
		    display: block; 
		  }
		<?php else: ?>
		  .h2-wrap, 
		  .container-fluid.container-articles { 
		    display: none; 
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_laptopslider', 1 ) ) : ?>
		  .laptop-slider { 
		    display: block; 
		  }
		<?php else: ?>
		  .laptop-slider { 
		    display: none; 
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_quoteslideshow', 1 ) ) : ?>
		  .quote-container, 
		  .shadow-container { 
		    display: block; 
		  }
		<?php else: ?>
		  .quote-container, 
		  .shadow-container { 
		    display: none; 
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_logo_frontpage', 1 ) && get_theme_mod( 'custom_logo' ) != '' ) : ?>
		  .banner .logo-image { 
			display: block;
		  }
		  .hero-title {
		    margin-top: 0;
		  }
		<?php else: ?>
		  .banner .logo-image { 
			display: none;
		  }
		  .hero-title {
		    margin-top: 240px;
		  }
		<?php endif; ?>
		<?php if ( get_theme_mod( 'display_logo_blogheader', 1 ) ) : ?>
		  .header-content .logo-image { 
			display: block;
		  }
		<?php else: ?>
		  .header-content .logo-image { 
			display: none;
		  }
		<?php endif; ?>
	  </style>
      <!--/Customizer CSS-->
      <?php
   }
   
   /**
    * This outputs the javascript needed to automate the live settings preview.
    * Also keep in mind that this function isn't necessary unless your settings 
    * are using 'transport'=>'postMessage' instead of the default 'transport'
    * => 'refresh'
    * 
    * Used by hook: 'customize_preview_init'
    * 
    * @see add_action('customize_preview_init',$func)
    * @since Up Front WP 1.0
    */
   public static function live_preview() {
      wp_enqueue_script( 
           'up-front-wp-themecustomizer', // Give the script a unique ID
           get_template_directory_uri() . '/js/theme-customizer.js', // Define the path to the JS file
           array(  'jquery', 'customize-preview' ), // Define dependencies
           '', // Define a version (optional) 
           true // Specify whether to put in footer (leave this true)
      );
   }
}

// Setup the Theme Customizer settings and controls...
add_action( 'customize_register' , array( 'Up_Front_WP_Customize' , 'register' ) );

// Output custom CSS to live site
add_action( 'wp_head' , array( 'Up_Front_WP_Customize' , 'header_output' ) );

// Enqueue live preview javascript in Theme Customizer admin screen
add_action( 'customize_preview_init' , array( 'Up_Front_WP_Customize' , 'live_preview' ) );

/**
 * Sanitize Customizer Checkbox
 * 
 * @link http://codex.wordpress.org/Theme_Customization_API
 * @since Up Front WP 1.0
 */
function up_front_wp_sanitize_checkbox( $input ) {
  if ( $input == 1 ) {
	return 1;
  } else {
	return '';
  }
}

/**
 * Sanitize Customizer Radio Buttons
 * 
 * @link http://codex.wordpress.org/Theme_Customization_API
 * @since Up Front WP 1.0
 */
function up_front_wp_sanitize_header_layout( $input ) {
    $valid = array(
        'full_width' => 'Full-width',
        'narrow' => 'Narrow',
    );
 
    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return '';
    }
}

function up_front_wp_sanitize_button_color( $input ) {
    $valid = array(
        'default' => 'Default Color',
        'extra' => 'Extra Color',
    );
 
    if ( array_key_exists( $input, $valid ) ) {
        return $input;
    } else {
        return '';
    }
}

if ( ! function_exists( 'up_front_wp_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own up_front_wp_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Up Front WP 1.0
 */
function up_front_wp_comment( $comment, $args, $depth ) {
  $GLOBALS['comment'] = $comment;
  switch ( $comment->comment_type ) :
	case 'pingback' :
	case 'trackback' :
	// Display trackbacks differently than normal comments.
  ?>
<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
  <p>
    <?php _e( 'Pingback:', 'up-front-wp' ); ?>
    <?php comment_author_link(); ?>
    <?php edit_comment_link( __( 'Edit', 'up-front-wp' ), '<span class="comment-meta edit-link"><span class="glyphicon glyphicon-pencil"></span> ', '</span>' ); ?>
  </p>
  <?php
	break;
	default :
	// Proceed with normal comments.
	global $post;
  ?>
<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
  <article id="comment-<?php comment_ID(); ?>" class="comment">
    <header class="comment-meta comment-author vcard">
      <?php
            echo get_avatar( $comment, 44 );
            printf( ' <cite><b class="fn">%1$s</b> %2$s</cite>',
                get_comment_author_link(),
                // If current post author is also comment author, make it known visually.
                ( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'up-front-wp' ) . '</span>' : ''
            );
            printf( '<span class="glyphicon glyphicon-calendar"></span> <a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
                esc_url( get_comment_link( $comment->comment_ID ) ),
                get_comment_time( 'c' ),
                /* translators: 1: date, 2: time */
                sprintf( __( '%1$s at %2$s', 'up-front-wp' ), get_comment_date(), get_comment_time() )
            );
        ?>
    </header>
    <!-- .comment-meta -->
    
    <?php if ( '0' == $comment->comment_approved ) : ?>
    <p class="comment-awaiting-moderation">
      <?php _e( 'Your comment is awaiting moderation.', 'up-front-wp' ); ?>
    </p>
    <?php endif; ?>
    <section class="comment-content comment">
      <?php comment_text(); ?>
      <?php edit_comment_link( __( 'Edit', 'up-front-wp' ), '<p class="comment-meta edit-link"><span class="glyphicon glyphicon-pencil"></span> ', '</p>' ); ?>
    </section>
    <!-- .comment-content -->
    
    <div class="reply">
      <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'up-front-wp' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    </div>
    <!-- .reply -->
    <hr />
  </article>
  <!-- #comment-## -->
  <?php
    break;
  endswitch; // end comment_type check
}

/**
 * Limit post title to 20 characters or less.
 *
 * @since Up Front WP 1.0
 */
function up_front_wp_short_title() {
  $title = get_the_title(); 
  $limit = "15";
  $pad="...";
  if(strlen($title) >= ($limit+3)) {
    $title = substr($title, 0, $limit) . $pad; }
    return $title;
}

/**
 * Get icon image path according to the MIME type.
 *
 * @since Up Front WP 1.0
 */
function up_front_wp_get_icon_for_attachment($post_id) {
  $base = get_template_directory_uri() . "/img/icons/";
  $type = get_post_mime_type($post_id);
  switch ($type) {
	case 'image/jpeg':
	case 'image/gif':
	case 'image/png':
	case 'image/bmp':
	case 'image/tiff':
	case 'image/x-icon':
	  return $base . "image.png"; break;
	case 'video/x-ms-asf':
	case 'video/x-ms-wmv':
	case 'video/x-ms-wmx':
	case 'video/x-ms-wm':
	case 'video/avi':
	case 'video/divx':
	case 'video/x-flv':
	case 'video/quicktime':
	case 'video/mpeg':
	case 'video/mp4':
	case 'video/ogg':
	case 'video/webm':
	case 'video/x-matroska':
	  return $base . "video.png"; break;
	case 'text/plain':
	case 'text/csv':
	case 'text/tab-separated-values':
	case 'text/calendar':
	case 'text/richtext':
	case 'text/css':
	case 'text/html':
      return $base . "text.png"; break;
	case 'audio/mpeg':
	case 'audio/x-realaudio':
	case 'audio/wav':
	case 'audio/ogg':
	case 'audio/midi':
	case 'audio/x-ms-wma':
	case 'audio/x-ms-wax':
	case 'audio/x-matroska':
	  return $base . "audio.png"; break;
    default:
      return $base . "file.png";
  }
}

/**
 * Convert Hex color values to RGB values.
 *
 * @since Up Front WP 1.0
 */
function up_front_wp_hex2rgb($hex) {
   $hex = str_replace("#", "", $hex);

   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   //return $rgb; // returns an array with the rgb values
}
endif;


